@@ -66,9 +66,14 @@ class Proxy():
             else:
                 self.amqpc = Proxy.__amqpc = Client(**kwargs)
 
-    async def start(self):
+    async def start(self, amqpc:BaseClient = None):
         """Query and set actor commands."""
 
+        if amqpc:
+            if self.amqpc:
+                await self.amqpc.stop()
+            self.amqpc = amqpc
+
         if not self.isAmqpcConnected():
             await self.amqpc.start()
 
@@ -81,6 +86,10 @@ class Proxy():
         """stop actor"""
         await self.__delattr_pull_commands_task(cancel=True)
 
+    @staticmethod
+    def getDefaultAmqpc():
+        return Proxy.__amqpc
+
     @staticmethod
     def setDefaultAmqpc(amqpc):
         Proxy.__amqpc = amqpc
